@@ -32,11 +32,13 @@ class Main():
     def __init__(self) -> None:
         colorama_init()
 
-    def __call__(self):
+    def __call__(self) -> None:
         user_agent, save_location, ffmpeg_location = self.__config()
         headers = {"User-Agent": user_agent}
         show_id = None
 
+        Path(save_location).mkdir(exist_ok=True)
+
         while not show_id:
             try:
                 show_id = int(input(f"{Fore.LIGHTYELLOW_EX}Show ID: {Fore.LIGHTWHITE_EX}"))
@@ -199,7 +201,7 @@ class Main():
 
         return tuple(config_default[key] for key in list(config_default.keys()))
 
-    def __config_create(self, path: Path):
+    def __config_create(self, path: Path) -> None:
         config = ConfigParser()
 
         config["default"] = {
